.. highlight: python
.. module:: shinqlx

.. shinqlx documentation

#####################
shinqlx documentation
#####################

********************************
High-level classes and functions
********************************

* :ref:`Plugins <plugin>`
* :ref:`Player <player>`
* :ref:`Game <game>`
* :ref:`Channels <channels>`
* :ref:`Database <database>`

*******************************
Low-level classes and functions
*******************************

* :ref:`Core functions <core>`
* :ref:`Commands <commands>`
* :ref:`EventDispatcher <events>`
* :ref:`Handlers <handlers>`
* :ref:`StatsListener <zmq>`

******************
Indices and tables
******************
* :ref:`genindex`

.. toctree::
   :hidden:

   plugin
   player
   game
   channels
   database
   shinqlx
   commands
   events
   handlers
   zmq

   genindex
   modindex
   search
